@@ -1,6 +1,6 @@
 #' compare_BIC compares the BIC of several outputs obtained with the same data.
 #' @title Compares the BIC of several outputs
-#' @author Marc Girondot
+#' @author Marc Girondot \email{marc.girondot@@gmail.com}
 #' @return A list with DeltaBIC and Akaike weight for the models.
 #' @param ... Successive results to be compared as lists.
 #' @param factor.value The $value of the list object is multiplied by factor.value to calculate BIC.
@@ -65,7 +65,8 @@ compare_BIC <- function(..., factor.value=-1, silent=FALSE, FUN=function(x) spec
           # Il faut que logLik(encours[[1]]) existe avec les attributs corrects
           # nall, nobs (nb d'observations) et df (nb de parametres)
           
-          t <- (class(try(logLik(encours[[1]]), silent=TRUE))=="try-error")
+          aaec <- try(logLik(encours[[1]]), silent=TRUE)
+          t <- (inherits(aaec, "try-error"))
           if (t) encours <- encours[[1]]
           
           sumL <- 0
@@ -74,7 +75,8 @@ compare_BIC <- function(..., factor.value=-1, silent=FALSE, FUN=function(x) spec
 
           for (j in 1:length(encours)) {
             encours2 <- encours[[j]]
-            t <- (class(try(logLik(encours2), silent=TRUE))=="try-error")
+            aaec <- try(logLik(encours2), silent=TRUE)
+            t <- (inherits(aaec, "try-error"))
             if (t) {
               stop(paste("Object", name[i], "has not the required format"))
             }
